==> ecs_1.4.0.orig.tar.gz: ecs-1.4.0/inc/base/ecs_param_perio_glob.h <==
#ifndef _ECS_PARAM_PERIO_PUBL_H_
#define _ECS_PARAM_PERIO_PUBL_H_

/*============================================================================
 *  Dfinition publique de la structure `ecs_param_perio_t' contenant
 *   les paramtres relatifs a la periodicite (rotation et translation)
 *============================================================================*/

/*
  This file is part of the Code_Saturne Preprocessor, element of the
  Code_Saturne CFD tool.

  Copyright (C) 1999-2007 EDF S.A., France

  contact: saturne-support@edf.fr

  The Code_Saturne Preprocessor is free software; you can redistribute it
  and/or modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2 of
  the License, or (at your option) any later version.

  The Code_Saturne Preprocessor is distributed in the hope that it will be
  useful, but WITHOUT ANY WARRANTY; without even the implied warranty
  of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with the Code_Saturne Preprocessor; if not, write to the
  Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor,
  Boston, MA  02110-1301  USA
*/


/*============================================================================
 *                                 Visibilit
 *============================================================================*/


/*----------------------------------------------------------------------------
 *  Fichiers `include' librairie standard C
 *----------------------------------------------------------------------------*/



/*----------------------------------------------------------------------------
 *  Fichiers `include' publics  du  paquetage global "Utilitaire"
 *----------------------------------------------------------------------------*/

#include "ecs_def.h"


/*----------------------------------------------------------------------------
 *  Fichiers `include' publics  des paquetages visibles
 *----------------------------------------------------------------------------*/



/*----------------------------------------------------------------------------
 *  Fichiers `include' publics  du  paquetage courant
 *----------------------------------------------------------------------------*/



/*============================================================================
 *                         Dfinitions d'numrations
 *============================================================================*/

/*----------------------------------------------------------------------------
 *  Type de priodicit considre
 *----------------------------------------------------------------------------*/

typedef enum {

  ECS_PERIO_TYPE_NUL          , /* Priodicit indfinie                      */
  ECS_PERIO_TYPE_TRANS        , /* Priodicit de translation                 */
  ECS_PERIO_TYPE_ROTA           /* Priodicit de rotation                    */

} ecs_perio_typ_t ;



/*============================================================================
 *                          Dfinitions de types
 *============================================================================*/

typedef struct _ecs_param_perio_t {

  ecs_int_t        num_perio ;       /* Numro de la priodicit              */
  ecs_perio_typ_t  type_perio ;      /* Translation ou rotation               */
  ecs_real_t       translation[3] ;  /* Vecteur translation                   */
  ecs_real_t       angle ;           /* Angle de la rotation                  */
  ecs_real_t       direction[3] ;    /* Vecteur rotation (axe de la rotation) */
  ecs_real_t       point_inv[3] ;    /* Point invariant de la rotation        */
  ecs_real_t       matrice[3][3] ;   /* Matrice de rotation                   */
                                     /* plus vecteur de translation           */

} ecs_param_perio_t ;



/*============================================================================
 *                        Dfinition de macros
 *============================================================================*/



#endif /* _ECS_PARAM_PERIO_PUBL_H_ */

==> ecs_2.0.0.rc1.orig.tar.gz: ecs-2.0.0-rc1/inc/base/ecs_param_perio_glob.h <==
#ifndef _ECS_PARAM_PERIO_GLOB_H_
#define _ECS_PARAM_PERIO_GLOB_H_

/*============================================================================
 *  Définition publique de la structure `ecs_param_perio_t' contenant
 *   les paramètres relatifs a la periodicite (rotation et translation)
 *============================================================================*/

/*
  This file is part of the Code_Saturne Preprocessor, element of the
  Code_Saturne CFD tool.

  Copyright (C) 1999-2007 EDF S.A., France

  contact: saturne-support@edf.fr

  The Code_Saturne Preprocessor is free software; you can redistribute it
  and/or modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2 of
  the License, or (at your option) any later version.

  The Code_Saturne Preprocessor is distributed in the hope that it will be
  useful, but WITHOUT ANY WARRANTY; without even the implied warranty
  of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with the Code_Saturne Preprocessor; if not, write to the
  Free Software Foundation, Inc.,
  51 Franklin St, Fifth Floor,
  Boston, MA  02110-1301  USA
*/


/*============================================================================
 *                                 Visibilité
 *============================================================================*/


/*----------------------------------------------------------------------------
 *  Fichiers `include' librairie standard C
 *----------------------------------------------------------------------------*/



/*----------------------------------------------------------------------------
 *  Fichiers `include' publics  du  paquetage global "Utilitaire"
 *----------------------------------------------------------------------------*/

#include "ecs_def.h"


/*----------------------------------------------------------------------------
 *  Fichiers `include' publics  des paquetages visibles
 *----------------------------------------------------------------------------*/



/*----------------------------------------------------------------------------
 *  Fichiers `include' publics  du  paquetage courant
 *----------------------------------------------------------------------------*/



/*============================================================================
 *                         Définitions d'énumérations
 *============================================================================*/

/*----------------------------------------------------------------------------
 *  Type de périodicité considérée
 *----------------------------------------------------------------------------*/

typedef enum {

  ECS_PERIO_TYPE_NUL          , /* Périodicité indéfinie                      */
  ECS_PERIO_TYPE_TRANS        , /* Périodicité de translation                 */
  ECS_PERIO_TYPE_ROTA           /* Périodicité de rotation                    */

} ecs_perio_typ_t ;



/*============================================================================
 *                          Définitions de types
 *============================================================================*/

typedef struct _ecs_param_perio_t {

  int              num_perio;        /* Numéro de la périodicité              */
  ecs_perio_typ_t  type_perio;       /* Translation ou rotation               */
  ecs_real_t       translation[3];   /* Vecteur translation                   */
  ecs_real_t       angle;            /* Angle de la rotation                  */
  ecs_real_t       direction[3];     /* Vecteur rotation (axe de la rotation) */
  ecs_real_t       point_inv[3];     /* Point invariant de la rotation        */
  ecs_real_t       matrice[3][3];    /* Matrice de rotation                   */
                                     /* plus vecteur de translation           */

} ecs_param_perio_t ;



/*============================================================================
 *                        Définition de macros
 *============================================================================*/



#endif /* _ECS_PARAM_PERIO_GLOB_H_ */
